@@ -4,13 +4,14 @@ import (
 	"strings"
 
 	"github.com/jesseduffield/gocui"
+	"github.com/jesseduffield/lazygit/pkg/commands/git_commands"
 	"github.com/jesseduffield/lazygit/pkg/commands/patch"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 )
 
 type StagingController struct {
 	baseController
-	*controllerCommon
+	c *ControllerCommon
 
 	context      types.IPatchExplorerContext
 	otherContext types.IPatchExplorerContext
@@ -22,17 +23,17 @@ type StagingController struct {
 var _ types.IController = &StagingController{}
 
 func NewStagingController(
-	common *controllerCommon,
+	common *ControllerCommon,
 	context types.IPatchExplorerContext,
 	otherContext types.IPatchExplorerContext,
 	staged bool,
 ) *StagingController {
 	return &StagingController{
-		baseController:   baseController{},
-		controllerCommon: common,
-		context:          context,
-		otherContext:     otherContext,
-		staged:           staged,
+		baseController: baseController{},
+		c:              common,
+		context:        context,
+		otherContext:   otherContext,
+		staged:         staged,
 	}
 }
 
@@ -41,12 +42,12 @@ func (self *StagingController) GetKeybindings(opts types.KeybindingsOpts) []*typ
 		{
 			Key:         opts.GetKey(opts.Config.Universal.OpenFile),
 			Handler:     self.OpenFile,
-			Description: self.c.Tr.LcOpenFile,
+			Description: self.c.Tr.OpenFile,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Universal.Edit),
 			Handler:     self.EditFile,
-			Description: self.c.Tr.LcEditFile,
+			Description: self.c.Tr.EditFile,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Universal.Return),
@@ -65,8 +66,8 @@ func (self *StagingController) GetKeybindings(opts types.KeybindingsOpts) []*typ
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Universal.Remove),
-			Handler:     self.ResetSelection,
-			Description: self.c.Tr.ResetSelection,
+			Handler:     self.DiscardSelection,
+			Description: self.c.Tr.DiscardSelection,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Main.EditSelectHunk),
@@ -75,17 +76,17 @@ func (self *StagingController) GetKeybindings(opts types.KeybindingsOpts) []*typ
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.CommitChanges),
-			Handler:     self.helpers.WorkingTree.HandleCommitPress,
+			Handler:     self.c.Helpers().WorkingTree.HandleCommitPress,
 			Description: self.c.Tr.CommitChanges,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.CommitChangesWithoutHook),
-			Handler:     self.helpers.WorkingTree.HandleWIPCommitPress,
-			Description: self.c.Tr.LcCommitChangesWithoutHook,
+			Handler:     self.c.Helpers().WorkingTree.HandleWIPCommitPress,
+			Description: self.c.Tr.CommitChangesWithoutHook,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.CommitChangesWithEditor),
-			Handler:     self.helpers.WorkingTree.HandleCommitEditorPress,
+			Handler:     self.c.Helpers().WorkingTree.HandleCommitEditorPress,
 			Description: self.c.Tr.CommitChangesWithEditor,
 		},
 	}
@@ -99,6 +100,29 @@ func (self *StagingController) GetMouseKeybindings(opts types.KeybindingsOpts) [
 	return []*gocui.ViewMouseBinding{}
 }
 
+func (self *StagingController) GetOnFocus() func(types.OnFocusOpts) error {
+	return func(opts types.OnFocusOpts) error {
+		self.c.Views().Staging.Wrap = false
+		self.c.Views().StagingSecondary.Wrap = false
+
+		return self.c.Helpers().Staging.RefreshStagingPanel(opts)
+	}
+}
+
+func (self *StagingController) GetOnFocusLost() func(types.OnFocusLostOpts) error {
+	return func(opts types.OnFocusLostOpts) error {
+		self.context.SetState(nil)
+
+		if opts.NewContextKey != self.otherContext.GetKey() {
+			self.c.Views().Staging.Wrap = true
+			self.c.Views().StagingSecondary.Wrap = true
+			_ = self.c.Contexts().Staging.Render(false)
+			_ = self.c.Contexts().StagingSecondary.Render(false)
+		}
+		return nil
+	}
+}
+
 func (self *StagingController) OpenFile() error {
 	self.context.GetMutex().Lock()
 	defer self.context.GetMutex().Unlock()
@@ -109,7 +133,7 @@ func (self *StagingController) OpenFile() error {
 		return nil
 	}
 
-	return self.helpers.Files.OpenFile(path)
+	return self.c.Helpers().Files.OpenFile(path)
 }
 
 func (self *StagingController) EditFile() error {
@@ -123,7 +147,7 @@ func (self *StagingController) EditFile() error {
 	}
 
 	lineNumber := self.context.GetState().CurrentLineNumber()
-	return self.helpers.Files.EditFileAtLine(path, lineNumber)
+	return self.c.Helpers().Files.EditFileAtLine(path, lineNumber)
 }
 
 func (self *StagingController) Escape() error {
@@ -142,13 +166,13 @@ func (self *StagingController) ToggleStaged() error {
 	return self.applySelectionAndRefresh(self.staged)
 }
 
-func (self *StagingController) ResetSelection() error {
+func (self *StagingController) DiscardSelection() error {
 	reset := func() error { return self.applySelectionAndRefresh(true) }
 
-	if !self.staged && !self.c.UserConfig.Gui.SkipUnstageLineWarning {
+	if !self.staged && !self.c.UserConfig.Gui.SkipDiscardChangeWarning {
 		return self.c.Confirm(types.ConfirmOpts{
-			Title:         self.c.Tr.UnstageLinesTitle,
-			Prompt:        self.c.Tr.UnstageLinesPrompt,
+			Title:         self.c.Tr.DiscardChangeTitle,
+			Prompt:        self.c.Tr.DiscardChangePrompt,
 			HandleConfirm: reset,
 		})
 	}
@@ -190,15 +214,14 @@ func (self *StagingController) applySelection(reverse bool) error {
 
 	// apply the patch then refresh this panel
 	// create a new temp file with the patch, then call git apply with that patch
-	applyFlags := []string{}
-	if reverse {
-		applyFlags = append(applyFlags, "reverse")
-	}
-	if !reverse || self.staged {
-		applyFlags = append(applyFlags, "cached")
-	}
 	self.c.LogAction(self.c.Tr.Actions.ApplyPatch)
-	err := self.git.WorkingTree.ApplyPatch(patchToApply, applyFlags...)
+	err := self.c.Git().Patch.ApplyPatch(
+		patchToApply,
+		git_commands.ApplyPatchOpts{
+			Reverse: reverse,
+			Cached:  !reverse || self.staged,
+		},
+	)
 	if err != nil {
 		return self.c.Error(err)
 	}
@@ -239,18 +262,18 @@ func (self *StagingController) editHunk() error {
 		}).
 		FormatPlain()
 
-	patchFilepath, err := self.git.WorkingTree.SaveTemporaryPatch(patchText)
+	patchFilepath, err := self.c.Git().Patch.SaveTemporaryPatch(patchText)
 	if err != nil {
 		return err
 	}
 
 	lineOffset := 3
 	lineIdxInHunk := state.GetSelectedLineIdx() - hunkStartIdx
-	if err := self.helpers.Files.EditFileAtLineAndWait(patchFilepath, lineIdxInHunk+lineOffset); err != nil {
+	if err := self.c.Helpers().Files.EditFileAtLineAndWait(patchFilepath, lineIdxInHunk+lineOffset); err != nil {
 		return err
 	}
 
-	editedPatchText, err := self.git.File.Cat(patchFilepath)
+	editedPatchText, err := self.c.Git().File.Cat(patchFilepath)
 	if err != nil {
 		return err
 	}
@@ -266,11 +289,13 @@ func (self *StagingController) editHunk() error {
 		}).
 		FormatPlain()
 
-	applyFlags := []string{"cached"}
-	if self.staged {
-		applyFlags = append(applyFlags, "reverse")
-	}
-	if err := self.git.WorkingTree.ApplyPatch(newPatchText, applyFlags...); err != nil {
+	if err := self.c.Git().Patch.ApplyPatch(
+		newPatchText,
+		git_commands.ApplyPatchOpts{
+			Reverse: self.staged,
+			Cached:  true,
+		},
+	); err != nil {
 		return self.c.Error(err)
 	}
 
@@ -278,5 +303,5 @@ func (self *StagingController) editHunk() error {
 }
 
 func (self *StagingController) FilePath() string {
-	return self.contexts.Files.GetSelectedPath()
+	return self.c.Contexts().Files.GetSelectedPath()
 }
