@@ -15,14 +15,14 @@ func (gui *Gui) handleCreateExtrasMenuPanel() error {
 			{
 				Label: gui.c.Tr.ToggleShowCommandLog,
 				OnPress: func() error {
-					currentContext := gui.currentStaticContext()
-					if gui.ShowExtrasWindow && currentContext.GetKey() == context.COMMAND_LOG_CONTEXT_KEY {
+					currentContext := gui.c.CurrentStaticContext()
+					if gui.c.State().GetShowExtrasWindow() && currentContext.GetKey() == context.COMMAND_LOG_CONTEXT_KEY {
 						if err := gui.c.PopContext(); err != nil {
 							return err
 						}
 					}
-					show := !gui.ShowExtrasWindow
-					gui.ShowExtrasWindow = show
+					show := !gui.c.State().GetShowExtrasWindow()
+					gui.c.State().SetShowExtrasWindow(show)
 					gui.c.GetAppState().HideCommandLog = !show
 					_ = gui.c.SaveAppState()
 					return nil
@@ -37,9 +37,9 @@ func (gui *Gui) handleCreateExtrasMenuPanel() error {
 }
 
 func (gui *Gui) handleFocusCommandLog() error {
-	gui.ShowExtrasWindow = true
+	gui.c.State().SetShowExtrasWindow(true)
 	// TODO: is this necessary? Can't I just call 'return from context'?
-	gui.State.Contexts.CommandLog.SetParentContext(gui.currentSideContext())
+	gui.State.Contexts.CommandLog.SetParentContext(gui.c.CurrentSideContext())
 	return gui.c.PushContext(gui.State.Contexts.CommandLog)
 }
 
@@ -72,13 +72,13 @@ type prefixWriter struct {
 	writer        io.Writer
 }
 
-func (self *prefixWriter) Write(p []byte) (n int, err error) {
+func (self *prefixWriter) Write(p []byte) (int, error) {
 	if !self.prefixWritten {
 		self.prefixWritten = true
 		// assuming we can write this prefix in one go
-		_, err = self.writer.Write([]byte(self.prefix))
+		n, err := self.writer.Write([]byte(self.prefix))
 		if err != nil {
-			return
+			return n, err
 		}
 	}
 	return self.writer.Write(p)
