@@ -1,17 +1,14 @@
 package presentation
 
 import (
+	"github.com/jesseduffield/generics/slices"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 )
 
 func GetSuggestionListDisplayStrings(suggestions []*types.Suggestion) [][]string {
-	lines := make([][]string, len(suggestions))
-
-	for i := range suggestions {
-		lines[i] = getSuggestionDisplayStrings(suggestions[i])
-	}
-
-	return lines
+	return slices.Map(suggestions, func(suggestion *types.Suggestion) []string {
+		return getSuggestionDisplayStrings(suggestion)
+	})
 }
 
 func getSuggestionDisplayStrings(suggestion *types.Suggestion) []string {
