@@ -184,7 +184,7 @@ func japaneseTranslationSet() TranslationSet {
 		RecentRepos: "最近使用したリポジトリ",
 		// MergeOptionsTitle:                   "Merge Options",
 		// RebaseOptionsTitle:                  "Rebase Options",
-		CommitMessageTitle:  "コミットメッセージ",
+		CommitSummaryTitle:  "コミットメッセージ",
 		LocalBranchesTitle:  "ブランチ",
 		SearchTitle:         "検索",
 		TagsTitle:           "タグ",
@@ -315,8 +315,8 @@ func japaneseTranslationSet() TranslationSet {
 		EditRemote:             "リモートを編集",
 		TagCommit:              "タグを作成",
 		TagMenuTitle:           "タグを作成",
-		TagNameTitle:           "タグ名:",
-		TagMessageTitle:        "タグメッセージ: ",
+		TagNameTitle:           "タグ名",
+		TagMessageTitle:        "タグメッセージ",
 		AnnotatedTag:           "注釈付きタグ",
 		LightweightTag:         "軽量タグ",
 		DeleteTag:              "タグを削除",
@@ -325,7 +325,6 @@ func japaneseTranslationSet() TranslationSet {
 		PushTagTitle:           "リモートにタグ '{{.tagName}}' をpush",
 		PushTag:                "タグをpush",
 		CreateTag:              "タグを作成",
-		CreateTagTitle:         "タグ名:",
 		FetchRemote:            "リモートをfetch",
 		FetchingRemoteStatus:   "リモートをfetch",
 		CheckoutCommit:         "コミットをチェックアウト",
