@@ -247,7 +247,7 @@ func traditionalChineseTranslationSet() TranslationSet {
 		RecentRepos:                         "最近的版本庫",
 		MergeOptionsTitle:                   "合併選項",
 		RebaseOptionsTitle:                  "變基選項",
-		CommitMessageTitle:                  "提交摘要",
+		CommitSummaryTitle:                  "提交摘要",
 		CommitDescriptionTitle:              "提交描述",
 		CommitDescriptionSubTitle:           "按 tab 切換焦點",
 		LocalBranchesTitle:                  "本地分支",
@@ -398,8 +398,8 @@ func traditionalChineseTranslationSet() TranslationSet {
 		EditRemote:                          "編輯遠端",
 		TagCommit:                           "打標籤到提交",
 		TagMenuTitle:                        "建立標籤",
-		TagNameTitle:                        "標籤名稱：",
-		TagMessageTitle:                     "標籤訊息：",
+		TagNameTitle:                        "標籤名稱",
+		TagMessageTitle:                     "標籤訊息",
 		AnnotatedTag:                        "附註標籤",
 		LightweightTag:                      "輕量標籤",
 		DeleteTag:                           "刪除標籤",
@@ -408,7 +408,6 @@ func traditionalChineseTranslationSet() TranslationSet {
 		PushTagTitle:                        "推送標籤 '{{.tagName}}' 至遠端：",
 		PushTag:                             "推送標籤",
 		CreateTag:                           "建立標籤",
-		CreateTagTitle:                      "標籤名稱：",
 		FetchRemote:                         "擷取遠端",
 		FetchingRemoteStatus:                "正在擷取遠端",
 		CheckoutCommit:                      "檢出提交",
