@@ -10,7 +10,7 @@ func (self *MenuDriver) getViewDriver() *ViewDriver {
 }
 
 // asserts that the popup has the expected title
-func (self *MenuDriver) Title(expected *Matcher) *MenuDriver {
+func (self *MenuDriver) Title(expected *TextMatcher) *MenuDriver {
 	self.getViewDriver().Title(expected)
 
 	self.hasCheckedTitle = true
@@ -30,24 +30,36 @@ func (self *MenuDriver) Cancel() {
 	self.getViewDriver().PressEscape()
 }
 
-func (self *MenuDriver) Select(option *Matcher) *MenuDriver {
+func (self *MenuDriver) Select(option *TextMatcher) *MenuDriver {
 	self.getViewDriver().NavigateToLine(option)
 
 	return self
 }
 
-func (self *MenuDriver) Lines(matchers ...*Matcher) *MenuDriver {
+func (self *MenuDriver) Lines(matchers ...*TextMatcher) *MenuDriver {
 	self.getViewDriver().Lines(matchers...)
 
 	return self
 }
 
-func (self *MenuDriver) TopLines(matchers ...*Matcher) *MenuDriver {
+func (self *MenuDriver) TopLines(matchers ...*TextMatcher) *MenuDriver {
 	self.getViewDriver().TopLines(matchers...)
 
 	return self
 }
 
+func (self *MenuDriver) Filter(text string) *MenuDriver {
+	self.getViewDriver().FilterOrSearch(text)
+
+	return self
+}
+
+func (self *MenuDriver) LineCount(matcher *IntMatcher) *MenuDriver {
+	self.getViewDriver().LineCount(matcher)
+
+	return self
+}
+
 func (self *MenuDriver) checkNecessaryChecksCompleted() {
 	if !self.hasCheckedTitle {
 		self.t.Fail("You must check the title of a menu popup by calling Title() before calling Confirm()/Cancel().")
