@@ -7,7 +7,7 @@ import (
 
 var SwitchTabFromMenu = NewIntegrationTest(NewIntegrationTestArgs{
 	Description:  "Switch tab via the options menu",
-	ExtraCmdArgs: "",
+	ExtraCmdArgs: []string{},
 	Skip:         false,
 	SetupConfig:  func(config *config.AppConfig) {},
 	SetupRepo: func(shell *Shell) {
@@ -16,8 +16,8 @@ var SwitchTabFromMenu = NewIntegrationTest(NewIntegrationTestArgs{
 		t.Views().Files().IsFocused().
 			Press(keys.Universal.OptionMenuAlt1)
 
-		t.ExpectPopup().Menu().Title(Equals("Menu")).
-			Select(Contains("next tab")).
+		t.ExpectPopup().Menu().Title(Equals("Keybindings")).
+			Select(Contains("Next tab")).
 			Confirm()
 
 		t.Views().Submodules().IsFocused()
